# Specification

## Overview

A button is a call to action that allows people to make a selection, navigate, send data, or take other types of actions.

This specification is an extension of [SDS Button Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md)

### Anatomy and Appearance

#### DOM Structure

[SDS Button - DOM Structure &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#dom-structure)

## API

### Properties & Attributes

[SDS Button - Properties & Attributes &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#properties--attributes)

Below are the list of attributes for `slds-button` in addition to existing ones for`sds-button`.

| Attribute | Type   | Values                                                                          | Default Value | Description                       |
| --------- | ------ | ------------------------------------------------------------------------------- | ------------- | --------------------------------- |
| `stretch` | `bool` | `true/false`                                                                    | `false`       | Toggle stretch styling of button  |
| `variant` | `enum` | `base/neutral/brand/brand-outline/destructive/destructive-text/success/inverse` | `neutral`     | Determines the type of the button |

#### Styling Hooks

> **Note:** Many interaction states do not differ from the default state. In these cases, the default fallback for those interaction states is the computed value of the preceding state.

#### Default

| Property Name                                       | CSS Property       | Fallback Value                   | Description                                                    |
| --------------------------------------------------- | ------------------ | -------------------------------- | -------------------------------------------------------------- |
| `--slds-c-button-icon-color-foreground`             | `color`            | `currentcolor`                   | Default icon color for buttons                                 |
| `--slds-c-button-neutral-spacing-inline`            | `padding-inline`   | `1rem`                           | Default inline padding for buttons                             |
| `--slds-c-button-neutral-spacing-block`             | `padding-block`    | `0`                              | Default vertical padding spacing for buttons                   |
| `--slds-c-button-neutral-font-lineheight`           | `line-height`      | `1.875rem`                       | Default line-height for buttons                                |
| `--slds-c-button-neutral-radius-border`             | `border-radius`    | `0.25rem`                        | Default border-radius for buttons                              |
| `--slds-c-button-neutral-color-background`          | `background-color` | `--sds-g-color-neutral-base-100` | Default background color for neutral buttons                   |
| `--slds-c-button-neutral-color-background-hover`    | `background-color` | `--sds-g-color-neutral-base-95`  | Default background color for neutral buttons on hover          |
| `--slds-c-button-neutral-color-background-focus`    | `background-color` | `--sds-g-color-neutral-base-95`  | Default background color for neutral buttons on focus          |
| `--slds-c-button-neutral-color-background-active`   | `background-color` | `--sds-g-color-neutral-base-90`  | Default background color for neutral buttons on active         |
| `--slds-c-button-neutral-color-background-disabled` | `background-color` | `--sds-g-color-neutral-base-100` | Default background color for neutral buttons when disabled     |
| `--slds-c-button-neutral-color-border`              | `border-color`     | `--sds-g-color-neutral-base-80`  | Default border color for neutral buttons                       |
| `--slds-c-button-neutral-color-border-hover`        | `border-color`     | `--sds-g-color-neutral-base-80`  | Default border color for neutral buttons on hover              |
| `--slds-c-button-neutral-color-border-focus`        | `border-color`     | `--sds-g-color-neutral-base-80`  | Default border color for neutral buttons on focus              |
| `--slds-c-button-neutral-color-border-active`       | `border-color`     | `--sds-g-color-neutral-base-80`  | Default border color for neutral buttons on active             |
| `--slds-c-button-neutral-color-border-disabled`     | `border-color`     | `--sds-g-color-neutral-base-80`  | Default border color for neutral buttons when disabled         |
| `--slds-c-button-neutral-text-color`                | `color`            | `--sds-g-color-brand-base-40`    | Default text color for neutral buttons                         |
| `--slds-c-button-neutral-text-color-hover`          | `color`            | `--sds-g-color-brand-base-30`    | Default text color for neutral buttons on hover                |
| `--slds-c-button-neutral-text-color-focus`          | `color`            | `--sds-g-color-brand-base-30`    | Default text color for neutral buttons on focus                |
| `--slds-c-button-neutral-text-color-active`         | `color`            | `--sds-g-color-brand-base-30`    | Default text color for neutral buttons on active               |
| `--slds-c-button-neutral-text-color-disabled`       | `color`            | `--sds-g-color-neutral-base-80`  | Default text color for neutral buttons when disabled           |
| `--slds-c-button-neutral-shadow`                    | `box shadow color` | `none`                           | Default box shadow color for neutral buttons (Must be defined) |
| `--slds-c-button-neutral-shadow-focus`              | `box shadow color` | `#0176d3 0 0 3px`                | Default box shadow color for neutral buttons when focused      |

#### Brand

| Property Name                                     | CSS Property       | Fallback Value                                   | Description                                              |
| ------------------------------------------------- | ------------------ | ------------------------------------------------ | -------------------------------------------------------- |
| `--slds-c-button-brand-color-background`          | `background-color` | `--sds-g-color-brand-base-50`                    | Default background color for brand buttons               |
| `--slds-c-button-brand-color-background-hover`    | `background-color` | `--sds-g-color-brand-base-30`                    | Default background color for brand buttons on hover      |
| `--slds-c-button-brand-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for brand buttons on focus      |
| `--slds-c-button-brand-color-background-active`   | `background-color` | `--sds-g-color-brand-base-20`                    | Default background color for brand buttons on active     |
| `--slds-c-button-brand-color-background-disabled` | `background-color` | `--sds-g-color-neutral-base-80`                  | Default background color for brand buttons when disabled |
| `--slds-c-button-brand-color-border`              | `border-color`     | `--sds-g-color-brand-base-50`                    | Default border color for brand buttons                   |
| `--slds-c-button-brand-color-border-hover`        | `border-color`     | `--sds-g-color-brand-base-30`                    | Default border color for brand buttons on hover          |
| `--slds-c-button-brand-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for brand buttons on focus          |
| `--slds-c-button-brand-color-border-active`       | `border-color`     | `--sds-g-color-brand-base-20`                    | Default border color for brand buttons on active         |
| `--slds-c-button-brand-color-border-disabled`     | `border-color`     | `--sds-g-color-neutral-base-80`                  | Default border color for brand buttons when disabled     |
| `--slds-c-button-brand-text-color`                | `color`            | `--sds-g-color-brand-base-100`                   | Default text color for brand buttons                     |
| `--slds-c-button-brand-text-color-hover`          | `color`            | `--slds-c-button-neutral-text-color`             | Default text color for brand buttons on hover            |
| `--slds-c-button-brand-text-color-focus`          | `color`            | `--slds-c-button-neutral-text-color-hover`       | Default text color for brand buttons on focus            |
| `--slds-c-button-brand-text-color-active`         | `color`            | `--slds-c-button-neutral-text-color-focus`       | Default text color for brand buttons on active           |
| `--slds-c-button-brand-text-color-disabled`       | `color`            | `--sds-g-color-neutral-base-100`                 | Default text color for brand buttons when disabled       |

#### Brand Outline

| Property Name                                            | CSS Property       | Fallback Value                                   | Description                                                      |
| -------------------------------------------------------- | ------------------ | ------------------------------------------------ | ---------------------------------------------------------------- |
| `--slds-c-button-brandoutline-color-background`          | `background-color` | `--sds-g-color-neutral-base-100`                 | Default background color for brand outline buttons               |
| `--slds-c-button-brandoutline-color-background-hover`    | `background-color` | `--sds-g-color-neutral-base-95`                  | Default background color for brand outline buttons on hover      |
| `--slds-c-button-brandoutline-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for brand outline buttons on focus      |
| `--slds-c-button-brandoutline-color-background-active`   | `background-color` | `--sds-g-color-neutral-base-90`                  | Default background color for brand outline buttons on active     |
| `--slds-c-button-brandoutline-color-background-disabled` | `background-color` |                                                  | Default background color for brand outline buttons when disabled |
| `--slds-c-button-brandoutline-color-border`              | `border-color`     | `--sds-g-color-brand-base-50`                    | Default border color for brand outline buttons                   |
| `--slds-c-button-brandoutline-color-border-hover`        | `border-color`     | `--slds-c-button-neutral-color-border`           | Default border color for brand outline buttons on hover          |
| `--slds-c-button-brandoutline-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for brand outline buttons on focus          |
| `--slds-c-button-brandoutline-color-border-active`       | `border-color`     | `--slds-c-button-neutral-color-border-focus`     | Default border color for brand outline buttons on active         |
| `--slds-c-button-brandoutline-color-border-disabled`     | `border-color`     |                                                  | Default border color for brand outline buttons when disabled     |
| `--slds-c-button-brandoutline-text-color`                | `color`            | `--sds-g-color-brand-base-40`                    | Default text color for brand outline buttons                     |
| `--slds-c-button-brandoutline-text-color-hover`          | `color`            | `--sds-g-color-brand-base-30`                    | Default text color for brand outline buttons on hover            |
| `--slds-c-button-brandoutline-text-color-focus`          | `color`            | `--slds-c-button-neutral-text-color-hover`       | Default text color for brand outline buttons on focus            |
| `--slds-c-button-brandoutline-text-color-active`         | `color`            | `--slds-c-button-neutral-text-color-focus`       | Default text color for brand outline buttons on active           |
| `--slds-c-button-brandoutline-text-color-disabled`       | `color`            |                                                  | Default text color for brand outline buttons when disabled       |

#### Inverse

| Property Name                                       | CSS Property       | Fallback Value                                   | Description                                                |
| --------------------------------------------------- | ------------------ | ------------------------------------------------ | ---------------------------------------------------------- |
| `--slds-c-button-inverse-color-background`          | `background-color` | `transparent`                                    | Default background color for inverse buttons               |
| `--slds-c-button-inverse-color-background-hover`    | `background-color` | `--sds-g-color-neutral-base-100`                 | Default background color for inverse buttons on hover      |
| `--slds-c-button-inverse-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for inverse buttons on focus      |
| `--slds-c-button-inverse-color-background-active`   | `background-color` | `--sds-g-color-neutral-base-95`                  | Default background color for inverse buttons on active     |
| `--slds-c-button-inverse-color-background-disabled` | `background-color` | `transparent`                                    | Default background color for inverse buttons when disabled |
| `--slds-c-button-inverse-color-border`              | `border-color`     | `--sds-g-color-brand-base-100`                   | Default border color for inverse buttons                   |
| `--slds-c-button-inverse-color-border-hover`        | `border-color`     | `--slds-c-button-neutral-color-border`           | Default border color for inverse buttons on hover          |
| `--slds-c-button-inverse-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for inverse buttons on focus          |
| `--slds-c-button-inverse-color-border-active`       | `border-color`     | `--slds-c-button-neutral-text-color-focus`       | Default border color for inverse buttons on active         |
| `--slds-c-button-inverse-color-border-disabled`     | `border-color`     | `--sds-g-color-neutral-base-60`                  | Default border color for inverse buttons when disabled     |
| `--slds-c-button-inverse-text-color`                | `color`            | `--sds-g-color-brand-base-100`                   | Default text color for inverse buttons                     |
| `--slds-c-button-inverse-text-color-hover`          | `color`            | `--sds-g-color-brand-base-50`                    | Default text color for inverse buttons on hover            |
| `--slds-c-button-inverse-text-color-focus`          | `color`            | `--slds-c-button-neutral-text-color-hover`       | Default text color for inverse buttons on focus            |
| `--slds-c-button-inverse-text-color-active`         | `color`            | `--slds-c-button-neutral-text-color-focus`       | Default text color for inverse buttons on active           |
| `--slds-c-button-inverse-text-color-disabled`       | `color`            |                                                  | Default text color for inverse buttons when disabled       |

#### Destructive

| Property Name                                           | CSS Property       | Fallback Value                                   | Description                                                    |
| ------------------------------------------------------- | ------------------ | ------------------------------------------------ | -------------------------------------------------------------- |
| `--slds-c-button-destructive-color-background`          | `background-color` | `--sds-g-color-error-base-40`                    | Default background color for destructive buttons               |
| `--slds-c-button-destructive-color-background-hover`    | `background-color` | `--sds-g-color-error-base-30`                    | Default background color for destructive buttons on hover      |
| `--slds-c-button-destructive-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for destructive buttons on focus      |
| `--slds-c-button-destructive-color-background-active`   | `background-color` | `--sds-g-color-error-base-20`                    | Default background color for destructive buttons on active     |
| `--slds-c-button-destructive-color-background-disabled` | `background-color` | `--sds-g-color-neutral-base-80`                  | Default background color for destructive buttons when disabled |
| `--slds-c-button-destructive-color-border`              | `border-color`     | `--sds-g-color-error-base-40`                    | Default border color for destructive buttons                   |
| `--slds-c-button-destructive-color-border-hover`        | `border-color`     | `--sds-g-color-error-base-30`                    | Default border color for destructive buttons on hover          |
| `--slds-c-button-destructive-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for destructive buttons on focus          |
| `--slds-c-button-destructive-color-border-active`       | `border-color`     | `--slds-c-button-neutral-color-border-focus`     | Default border color for destructive buttons on active         |
| `--slds-c-button-destructive-color-border-disabled`     | `border-color`     | `--sds-g-color-neutral-base-80`                  | Default border color for destructive buttons when disabled     |
| `--slds-c-button-destructive-text-color`                | `color`            | `--sds-g-color-error-base-100`                   | Default text color for destructive buttons                     |
| `--slds-c-button-destructive-text-color-hover`          | `color`            | `--slds-c-button-neutral-text-color`             | Default text color for destructive buttons on hover            |
| `--slds-c-button-destructive-text-color-focus`          | `color`            | `--slds-c-button-neutral-text-color-hover`       | Default text color for destructive buttons on focus            |
| `--slds-c-button-destructive-text-color-active`         | `color`            | `--slds-c-button-neutral-text-color-focus`       | Default text color for destructive buttons on active           |
| `--slds-c-button-destructive-text-color-disabled`       | `color`            | `--sds-g-color-neutral-base-100`                 | Default text color for destructive buttons when disabled       |

#### Destructive Text

| Property Name                                               | CSS Property       | Fallback Value                                   | Description                                                         |
| ----------------------------------------------------------- | ------------------ | ------------------------------------------------ | ------------------------------------------------------------------- |
| `--slds-c-button-destructivetext-color-background`          | `background-color` | `--sds-g-color-neutral-base-100`                 | Default background color for destructive text buttons               |
| `--slds-c-button-destructivetext-color-background-hover`    | `background-color` | `--sds-g-color-neutral-base-95`                  | Default background color for destructive text buttons on hover      |
| `--slds-c-button-destructivetext-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for destructive text buttons on focus      |
| `--slds-c-button-destructivetext-color-background-active`   | `background-color` | `--sds-g-color-neutral-base-90`                  | Default background color for destructive text buttons on active     |
| `--slds-c-button-destructivetext-color-background-disabled` | `background-color` |                                                  | Default background color for destructive text buttons when disabled |
| `--slds-c-button-destructivetext-color-border`              | `border-color`     | `--sds-g-color-neutral-base-80`                  | Default border color for destructive text buttons                   |
| `--slds-c-button-destructivetext-color-border-hover`        | `border-color`     | `--slds-c-button-neutral-color-border`           | Default border color for destructive text buttons on hover          |
| `--slds-c-button-destructivetext-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for destructive text buttons on focus          |
| `--slds-c-button-destructivetext-color-border-active`       | `border-color`     | `--slds-c-button-neutral-color-border-focus`     | Default border color for destructive text buttons on active         |
| `--slds-c-button-destructivetext-color-border-disabled`     | `border-color`     |                                                  | Default border color for destructive text buttons when disabled     |
| `--slds-c-button-destructivetext-text-color`                | `color`            | `--sds-g-color-error-base-50`                    | Default text color for destructive text buttons                     |
| `--slds-c-button-destructivetext-text-color-hover`          | `color`            | `--sds-g-color-error-base-40`                    | Default text color for destructive text buttons on hover            |
| `--slds-c-button-destructivetext-text-color-focus`          | `color`            | `--slds-c-button-neutral-text-color-hover`       | Default text color for destructive text buttons on focus            |
| `--slds-c-button-destructivetext-text-color-active`         | `color`            | `--slds-c-button-neutral-text-color-focus`       | Default text color for destructive text buttons on active           |
| `--slds-c-button-destructivetext-text-color-disabled`       | `color`            |                                                  | Default text color for destructive text buttons when disabled       |

#### Success

| Property Name                                       | CSS Property       | Fallback Value                                   | Description                                                |
| --------------------------------------------------- | ------------------ | ------------------------------------------------ | ---------------------------------------------------------- |
| `--slds-c-button-success-color-background`          | `background-color` | `--sds-g-color-success-base-50`                  | Default background color for success buttons               |
| `--slds-c-button-success-color-background-hover`    | `background-color` | `--sds-g-color-success-base-40`                  | Default background color for success buttons on hover      |
| `--slds-c-button-success-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for success buttons on focus      |
| `--slds-c-button-success-color-background-active`   | `background-color` | `--sds-g-color-success-base-30`                  | Default background color for success buttons on active     |
| `--slds-c-button-success-color-background-disabled` | `background-color` | `--sds-g-color-neutral-base-80`                  | Default background color for success buttons when disabled |
| `--slds-c-button-success-color-border`              | `border-color`     | `--sds-g-color-success-base-50`                  | Default border color for success buttons                   |
| `--slds-c-button-success-color-border-hover`        | `border-color`     | `--sds-g-color-success-base-40`                  | Default border color for success buttons on hover          |
| `--slds-c-button-success-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for success buttons on focus          |
| `--slds-c-button-success-color-border-active`       | `border-color`     | `--slds-c-button-neutral-color-border-focus`     | Default border color for success buttons on active         |
| `--slds-c-button-success-color-border-disabled`     | `border-color`     | `--sds-g-color-neutral-base-80`                  | Default border color for success buttons when disabled     |
| `--slds-c-button-success-text-color`                | `color`            | `--sds-g-color-success-base-100`                 | Default text color for success buttons                     |
| `--slds-c-button-success-text-color-hover`          | `color`            | `--slds-c-button-neutral-text-color`             | Default text color for success buttons on hover            |
| `--slds-c-button-success-text-color-focus`          | `color`            | `--slds-c-button-neutral-text-color-hover`       | Default text color for success buttons on focus            |
| `--slds-c-button-success-text-color-active`         | `color`            | `--slds-c-button-neutral-text-color-focus`       | Default text color for success buttons on active           |
| `--slds-c-button-success-text-color-disabled`       | `color`            | `--sds-g-color-neutral-base-100`                 | Default text color for success buttons when disabled       |

#### Base (Text in LBC)

> **Note:** 'base' variant is not the default in LBC. But it is the default variant in the light DOM version of SLDS. So even though this is a non-default variant in this context, the hooks for this variant are written as the default for interoperability with SLDS light DOM. E.g., `--slds-c-button-color-background`.

| Property Name                               | CSS Property       | Fallback Value                                   | Description                                             |
| ------------------------------------------- | ------------------ | ------------------------------------------------ | ------------------------------------------------------- |
| `--slds-c-button-spacing-inline`            | `padding-inline`   | `0`                                              | Default inline padding for buttons                      |
| `--slds-c-button-color-background`          | `background-color` | `transparent`                                    | Default background color for base buttons               |
| `--slds-c-button-color-background-hover`    | `background-color` | `--slds-c-button-neutral-color-background`       | Default background color for base buttons on hover      |
| `--slds-c-button-color-background-focus`    | `background-color` | `--slds-c-button-neutral-color-background-hover` | Default background color for base buttons on focus      |
| `--slds-c-button-color-background-active`   | `background-color` | `--slds-c-button-neutral-color-background-focus` | Default background color for base buttons on active     |
| `--slds-c-button-color-background-disabled` | `background-color` | `transparent`                                    | Default background color for base buttons when disabled |
| `--slds-c-button-color-border`              | `border-color`     | `transparent`                                    | Default border color for base buttons                   |
| `--slds-c-button-color-border-hover`        | `border-color`     | `--slds-c-button-neutral-color-border`           | Default border color for base buttons on hover          |
| `--slds-c-button-color-border-focus`        | `border-color`     | `--slds-c-button-neutral-color-border-hover`     | Default border color for base buttons on focus          |
| `--slds-c-button-color-border-active`       | `border-color`     | `--slds-c-button-neutral-color-border-focus`     | Default border color for base buttons on active         |
| `--slds-c-button-color-border-disabled`     | `border-color`     | `transparent`                                    | Default border color for base buttons when disabled     |
| `--slds-c-button-text-color`                | `color`            | `--sds-g-color-brand-base-40`                    | Default text color for base buttons                     |
| `--slds-c-button-text-color-hover`          | `color`            | `--slds-c-button-text-color`                     | Default text color for base buttons on hover            |
| `--slds-c-button-text-color-focus`          | `color`            | `--slds-c-button-text-color-hover`               | Default text color for base buttons on focus            |
| `--slds-c-button-text-color-active`         | `color`            | `--slds-c-button-text-color-focus`               | Default text color for base buttons on active           |
| `--slds-c-button-text-color-disabled`       | `color`            |                                                  | Default text color for base buttons when disabled       |

## Accessibility

[SDS Button - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#accessibility)

## Internationalization

[SDS Button - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#internationalization)

## Test Plan

[SDS Button - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#test-plan)
